@@ -1,4 +1,4 @@
-from __future__ import unicode_literals, print_function, absolute_import
+from __future__ import print_function, absolute_import
 
 import sys
 from os import path as op, chmod
