@@ -4,7 +4,7 @@
     MIT License.
 """
 from __future__ import (
-    unicode_literals, print_function, absolute_import, with_statement
+    print_function, absolute_import, with_statement
 )
 
 import sys
